==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/unittest/gunit/gunit_test_main.h <==
/* Copyright (c) 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include "my_inttypes.h"
#include "my_sys.h"

class THD;
struct MEM_ROOT;

// Some globals needed for "small" tests.

extern mysql_mutex_t LOCK_open;
extern uint opt_debug_sync_timeout;
extern thread_local MEM_ROOT **THR_MALLOC;
extern thread_local THD *current_thd;
extern size_t malloc_chunk_size;

extern "C" void sql_alloc_error_handler(void);
extern int compare_malloc_chunks(void *a, void *b, size_t);

==> mysql-8.4_8.4.6.orig.tar.gz: mysql-8.4.6/unittest/gunit/gunit_test_main.h <==
/* Copyright (c) 2021, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include "my_inttypes.h"
#include "my_sys.h"

class THD;
struct MEM_ROOT;

// Some globals needed for "small" tests.

extern mysql_mutex_t LOCK_open;
extern uint opt_debug_sync_timeout;
extern thread_local MEM_ROOT **THR_MALLOC;
extern thread_local THD *current_thd;
extern size_t malloc_chunk_size;

extern "C" void sql_alloc_error_handler(void);
extern int compare_malloc_chunks(void *a, void *b, size_t);
